==> aws-cdk.aws-devopsguru-1.139.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_devopsguru_CfnNotificationChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.config))
        _aws_cdk_aws_devopsguru_CfnNotificationChannel_NotificationChannelConfigProperty(p.config);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_devopsguru_CfnResourceCollectionProps(p) {
}
function _aws_cdk_aws_devopsguru_CfnNotificationChannel(p) {
}
function _aws_cdk_aws_devopsguru_CfnNotificationChannel_SnsChannelConfigProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection_CloudFormationCollectionFilterProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnNotificationChannel_NotificationChannelConfigProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection_ResourceCollectionFilterProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_devopsguru_CfnNotificationChannelProps, _aws_cdk_aws_devopsguru_CfnResourceCollectionProps, _aws_cdk_aws_devopsguru_CfnNotificationChannel, _aws_cdk_aws_devopsguru_CfnNotificationChannel_SnsChannelConfigProperty, _aws_cdk_aws_devopsguru_CfnResourceCollection, _aws_cdk_aws_devopsguru_CfnResourceCollection_CloudFormationCollectionFilterProperty, _aws_cdk_aws_devopsguru_CfnNotificationChannel_NotificationChannelConfigProperty, _aws_cdk_aws_devopsguru_CfnResourceCollection_ResourceCollectionFilterProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-devopsguru-1.150.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_devopsguru_CfnNotificationChannelProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.config))
        _aws_cdk_aws_devopsguru_CfnNotificationChannel_NotificationChannelConfigProperty(p.config);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_devopsguru_CfnResourceCollectionProps(p) {
}
function _aws_cdk_aws_devopsguru_CfnNotificationChannel(p) {
}
function _aws_cdk_aws_devopsguru_CfnNotificationChannel_SnsChannelConfigProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection_CloudFormationCollectionFilterProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection_TagCollectionProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnNotificationChannel_NotificationChannelConfigProperty(p) {
}
function _aws_cdk_aws_devopsguru_CfnResourceCollection_ResourceCollectionFilterProperty(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        _aws_cdk_aws_devopsguru_CfnResourceCollection_TagCollectionProperty(p.tags);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_devopsguru_CfnNotificationChannelProps, _aws_cdk_aws_devopsguru_CfnResourceCollectionProps, _aws_cdk_aws_devopsguru_CfnNotificationChannel, _aws_cdk_aws_devopsguru_CfnNotificationChannel_SnsChannelConfigProperty, _aws_cdk_aws_devopsguru_CfnResourceCollection, _aws_cdk_aws_devopsguru_CfnResourceCollection_CloudFormationCollectionFilterProperty, _aws_cdk_aws_devopsguru_CfnResourceCollection_TagCollectionProperty, _aws_cdk_aws_devopsguru_CfnNotificationChannel_NotificationChannelConfigProperty, _aws_cdk_aws_devopsguru_CfnResourceCollection_ResourceCollectionFilterProperty };
module.exports.DeprecationError = DeprecationError;
